@@ -13,9 +13,13 @@ typedef Eo Ecore_Audio_Out;
 
 
 #endif
+/** Ecore Audio output object.
+ *
+ * @ingroup Ecore_Audio_Out
+ */
 #define ECORE_AUDIO_OUT_CLASS ecore_audio_out_class_get()
 
-EAPI const Eo_Class *ecore_audio_out_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *ecore_audio_out_class_get(void);
 
 /**
  * @brief Attach an input to an output
@@ -28,7 +32,7 @@ EAPI const Eo_Class *ecore_audio_out_class_get(void) EINA_CONST;
  *
  * @ingroup Ecore_Audio_Out
  */
-EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Ecore_Audio_In *input);
+EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Eo *obj, Ecore_Audio_In *input);
 
 /**
  * @brief Detach an input from an output
@@ -41,7 +45,7 @@ EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Ecore_Audio_In *input);
  *
  * @ingroup Ecore_Audio_Out
  */
-EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Ecore_Audio_In *input);
+EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Eo *obj, Ecore_Audio_In *input);
 
 /**
  * @brief Returns the list of all attached inputs
@@ -52,7 +56,7 @@ EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Ecore_Audio_In *input);
  *
  * @ingroup Ecore_Audio_Out
  */
-EOAPI Eina_List *ecore_audio_obj_out_inputs_get(void);
+EOAPI Eina_List *ecore_audio_obj_out_inputs_get(Eo *obj);
 
 
 #endif
