@@ -15,16 +15,7 @@ typedef Eo Efl_Control;
 #endif
 #define EFL_CONTROL_INTERFACE efl_control_interface_get()
 
-EAPI const Eo_Class *efl_control_interface_get(void) EINA_CONST;
-
-/**
- * @brief Control the priority of the object.
- *
- * @param[in] priority The priority of the object
- *
- * @ingroup Efl_Control
- */
-EOAPI void  efl_control_priority_set(int priority);
+EWAPI const Eo_Class *efl_control_interface_get(void);
 
 /**
  * @brief Control the priority of the object.
@@ -33,16 +24,16 @@ EOAPI void  efl_control_priority_set(int priority);
  *
  * @ingroup Efl_Control
  */
-EOAPI int  efl_control_priority_get(void);
+EOAPI int efl_control_priority_get(const Eo *obj);
 
 /**
- * @brief Controls whether the object is suspended or not.
+ * @brief Control the priority of the object.
  *
- * @param[in] suspend Controls whether the object is suspended or not.
+ * @param[in] priority The priority of the object
  *
  * @ingroup Efl_Control
  */
-EOAPI void  efl_control_suspend_set(Eina_Bool suspend);
+EOAPI void efl_control_priority_set(Eo *obj, int priority);
 
 /**
  * @brief Controls whether the object is suspended or not.
@@ -51,7 +42,16 @@ EOAPI void  efl_control_suspend_set(Eina_Bool suspend);
  *
  * @ingroup Efl_Control
  */
-EOAPI Eina_Bool  efl_control_suspend_get(void);
+EOAPI Eina_Bool efl_control_suspend_get(const Eo *obj);
+
+/**
+ * @brief Controls whether the object is suspended or not.
+ *
+ * @param[in] suspend Controls whether the object is suspended or not.
+ *
+ * @ingroup Efl_Control
+ */
+EOAPI void efl_control_suspend_set(Eo *obj, Eina_Bool suspend);
 
 
 #endif
