@@ -15,7 +15,19 @@ typedef Eo Efl_Gfx_Stack;
 #endif
 #define EFL_GFX_STACK_INTERFACE efl_gfx_stack_interface_get()
 
-EAPI const Eo_Class *efl_gfx_stack_interface_get(void) EINA_CONST;
+EWAPI const Eo_Class *efl_gfx_stack_interface_get(void);
+
+/**
+ * @brief Retrieves the layer of its canvas that the given object is part of.
+ *
+ * See also @ref efl_gfx_stack_layer_set()
+ *
+ * @return The number of the layer to place the object on. Must be between
+ * #EVAS_LAYER_MIN and #EVAS_LAYER_MAX.
+ *
+ * @ingroup Efl_Gfx_Stack
+ */
+EOAPI short efl_gfx_stack_layer_get(const Eo *obj);
 
 /**
  * @brief Sets the layer of its canvas that the given object will be part of.
@@ -39,19 +51,7 @@ EAPI const Eo_Class *efl_gfx_stack_interface_get(void) EINA_CONST;
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void  efl_gfx_stack_layer_set(short l);
-
-/**
- * @brief Retrieves the layer of its canvas that the given object is part of.
- *
- * See also @ref efl_gfx_stack_layer_set()
- *
- * @return The number of the layer to place the object on. Must be between
- * #EVAS_LAYER_MIN and #EVAS_LAYER_MAX.
- *
- * @ingroup Efl_Gfx_Stack
- */
-EOAPI short  efl_gfx_stack_layer_get(void);
+EOAPI void efl_gfx_stack_layer_set(Eo *obj, short l);
 
 /**
  * @brief Get the Evas object stacked right below @c obj
@@ -67,7 +67,7 @@ EOAPI short  efl_gfx_stack_layer_get(void);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI Efl_Gfx_Stack * efl_gfx_stack_below_get(void);
+EOAPI Efl_Gfx_Stack *efl_gfx_stack_below_get(const Eo *obj);
 
 /**
  * @brief Get the Evas object stacked right above @c obj
@@ -83,7 +83,7 @@ EOAPI Efl_Gfx_Stack * efl_gfx_stack_below_get(void);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI Efl_Gfx_Stack * efl_gfx_stack_above_get(void);
+EOAPI Efl_Gfx_Stack *efl_gfx_stack_above_get(const Eo *obj);
 
 /**
  * @brief Stack @c obj immediately @c below
@@ -109,7 +109,7 @@ EOAPI Efl_Gfx_Stack * efl_gfx_stack_above_get(void);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void  efl_gfx_stack_below(Efl_Gfx_Stack *below);
+EOAPI void efl_gfx_stack_below(Eo *obj, Efl_Gfx_Stack *below);
 
 /**
  * @brief Raise @c obj to the top of its layer.
@@ -122,7 +122,7 @@ EOAPI void  efl_gfx_stack_below(Efl_Gfx_Stack *below);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void  efl_gfx_stack_raise(void);
+EOAPI void efl_gfx_stack_raise(Eo *obj);
 
 /**
  * @brief Stack @c obj immediately @c above
@@ -148,7 +148,7 @@ EOAPI void  efl_gfx_stack_raise(void);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void  efl_gfx_stack_above(Efl_Gfx_Stack *above);
+EOAPI void efl_gfx_stack_above(Eo *obj, Efl_Gfx_Stack *above);
 
 /**
  * @brief Lower @c obj to the bottom of its layer.
@@ -161,7 +161,14 @@ EOAPI void  efl_gfx_stack_above(Efl_Gfx_Stack *above);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void  efl_gfx_stack_lower(void);
+EOAPI void efl_gfx_stack_lower(Eo *obj);
 
+EOAPI extern const Eo_Event_Description _EFL_GFX_EVENT_RESTACK;
+
+/** Object stacking was changed.
+ *
+ * @ingroup Efl_Gfx_Stack
+ */
+#define EFL_GFX_EVENT_RESTACK (&(_EFL_GFX_EVENT_RESTACK))
 
 #endif
