@@ -13,20 +13,25 @@ typedef Eo Eldbus_Model_Signal;
 
 
 #endif
+/** Eldbus model signal class
+ *
+ * @ingroup Eldbus_Model_Signal
+ */
 #define ELDBUS_MODEL_SIGNAL_CLASS eldbus_model_signal_class_get()
 
-EAPI const Eo_Class *eldbus_model_signal_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *eldbus_model_signal_class_get(void);
 
 /**
  * @brief Custom Eldbus_Model_Signal constructor.
  *
+ * @param[in] proxy Eldbus proxy
  * @param[in] signal The introspected method
  *
  * @since 1.16
  *
  * @ingroup Eldbus_Model_Signal
  */
-EOAPI void eldbus_model_signal_constructor(Eldbus_Proxy *proxy, const Eldbus_Introspection_Signal *signal);
+EOAPI void eldbus_model_signal_constructor(Eo *obj, Eldbus_Proxy *proxy, const Eldbus_Introspection_Signal *signal);
 
 
 #endif
