@@ -16,105 +16,6 @@ typedef unsigned long long Evas_Modifier_Mask;
  */
 typedef int Evas_Coord;
 
-/** Aspect types/policies for scaling size hints, used for
- * evas_object_size_hint_aspect_set()
- *
- * @ingroup Evas
- */
-typedef enum
-{
-  EVAS_ASPECT_CONTROL_NONE = 0, /** Preference on scaling unset */
-  EVAS_ASPECT_CONTROL_NEITHER = 1, /** Same effect as unset preference on
-                                    * scaling */
-  EVAS_ASPECT_CONTROL_HORIZONTAL = 2, /** Use all horizontal container space to
-                                       * place an object, using the given
-                                       * aspect */
-  EVAS_ASPECT_CONTROL_VERTICAL = 3, /** Use all vertical container space to
-                                     * place an object, using the given aspect
-                                     */
-  EVAS_ASPECT_CONTROL_BOTH = 4 /** Use all horizontal and vertical container
-                                * spaces to place an object (never growing it
-                                * out of those bounds), using the given aspect
-                                */
-} Evas_Aspect_Control;
-
-/** How the object should be rendered to output.
- *
- * @ingroup Evas
- */
-typedef enum
-{
-  EVAS_RENDER_BLEND = 0, /** Default render operation: d = d*(1-sa) + s. The
-                          * object will be merged onto the bottom objects using
-                          * simple alpha compositing (a over b). */
-  EVAS_RENDER_BLEND_REL = 1, /** DEPRECATED. d = d*(1 - sa) + s*da */
-  EVAS_RENDER_COPY = 2, /** Copy mode, d = s. The object's pixels will replace
-                         * everything that was below, effectively hiding them.
-                         */
-  EVAS_RENDER_COPY_REL = 3, /** DEPRECATED. d = s*da */
-  EVAS_RENDER_ADD = 4, /** DEPRECATED. d = d + s */
-  EVAS_RENDER_ADD_REL = 5, /** DEPRECATED. d = d + s*da */
-  EVAS_RENDER_SUB = 6, /** DEPRECATED. d = d - s */
-  EVAS_RENDER_SUB_REL = 7, /** DEPRECATED. d = d - s*da */
-  EVAS_RENDER_TINT = 8, /** DEPRECATED. d = d*s + d*(1 - sa) + s*(1 - da) */
-  EVAS_RENDER_TINT_REL = 9, /** DEPRECATED. d = d*(1 - sa + s) */
-  EVAS_RENDER_MASK = 10, /** DEPRECATED. d = d*sa. For masking support, please
-                          * use Evas.Object.clip_set or EDC "clip_to" instead.
-                          */
-  EVAS_RENDER_MUL = 11 /** DEPRECATED. d = d*s */
-} Evas_Render_Op;
-
-/**
- * @brief How the mouse pointer should be handled by Evas.
- *
- * In the mode #EVAS_OBJECT_POINTER_MODE_AUTOGRAB, when a mouse button is
- * pressed down over an object and held, with the mouse pointer being moved
- * outside of it, the pointer still behaves as being bound to that object,
- * albeit out of its drawing region. When the button is released, the event
- * will be fed to the object, that may check if the final position is over it
- * or not and do something about it.
- *
- * In the mode #EVAS_OBJECT_POINTER_MODE_NOGRAB, the pointer will always be
- * bound to the object right below it.
- *
- * @ingroup Evas
- */
-typedef enum
-{
-  EVAS_OBJECT_POINTER_MODE_AUTOGRAB = 0, /** default, X11-like */
-  EVAS_OBJECT_POINTER_MODE_NOGRAB, /** pointer always bound to the object right
-                                    * below it */
-  EVAS_OBJECT_POINTER_MODE_NOGRAB_NO_REPEAT_UPDOWN /** useful on object with
-                                                    * "repeat events" enabled,
-                                                    * where mouse/touch up and
-                                                    * down events WONT be
-                                                    * repeated to objects and
-                                                    * these objects wont be
-                                                    * auto-grabbed.
-                                                    *
-                                                    * @since 1.2 */
-} Evas_Object_Pointer_Mode;
-
-typedef enum
-{
-  EVAS_DISPLAY_MODE_NONE = 0, /** Default mode */
-  EVAS_DISPLAY_MODE_COMPRESS = 1, /** Use this mode when you want to give
-                                   * compress display mode hint to an object */
-  EVAS_DISPLAY_MODE_EXPAND = 2, /** Use this mode when you want to give expand
-                                 * display mode hint to an object */
-  EVAS_DISPLAY_MODE_DONT_CHANGE = 3 /** Use this mode when an object should not
-                                     * change its display mode */
-} Evas_Display_Mode;
-
-typedef enum
-{
-  EVAS_BIDI_DIRECTION_NATURAL = 0,
-  EVAS_BIDI_DIRECTION_NEUTRAL = 0,
-  EVAS_BIDI_DIRECTION_LTR,
-  EVAS_BIDI_DIRECTION_RTL,
-  EVAS_BIDI_DIRECTION_INHERIT
-} Evas_BiDi_Direction;
-
 /** Types of styles to be applied on text objects. The
  * EVAS_TEXT_STYLE_SHADOW_DIRECTION_* ones are to be ORed together with others
  * imposing shadow, to change shadow's direction
@@ -165,54 +66,6 @@ typedef enum
   EVAS_FONT_HINTING_BYTECODE /** Bytecode font hinting */
 } Evas_Font_Hinting_Flags;
 
-/**
- * @brief An opaque handle to map points
- *
- * See @ref evas_map_new, @ref evas_map_free, @ref evas_map_dup.
- *
- * @ingroup Evas
- */
-typedef struct _Evas_Map Evas_Map;
-
-/** Flags for Mouse Button events
- *
- * @ingroup Evas
- */
-typedef enum
-{
-  EVAS_BUTTON_NONE = 0, /** No extra mouse button data */
-  EVAS_BUTTON_DOUBLE_CLICK = 1 /* 1 << 0 */, /** This mouse button press was
-                                              * the 2nd press of a double click
-                                              */
-  EVAS_BUTTON_TRIPLE_CLICK = 2 /* 1 << 1 */ /** This mouse button press was the
-                                             * 3rd press of a triple click */
-} Evas_Button_Flags;
-
-/** Flags for Events
- *
- * @ingroup Evas
- */
-typedef enum
-{
-  EVAS_EVENT_FLAG_NONE = 0, /** No fancy flags set */
-  EVAS_EVENT_FLAG_ON_HOLD = 1 /* 1 << 0 */, /** This event is being delivered
-                                             * but should be put "on hold"
-                                             * until the on hold flag is unset.
-                                             * The event should be used for
-                                             * informational purposes and maybe
-                                             * some indications visually, but
-                                             * not actually perform anything */
-  EVAS_EVENT_FLAG_ON_SCROLL = 2 /* 1 << 1 */ /** This event flag indicates the
-                                              * event occurs while scrolling;
-                                              * for example, DOWN event occurs
-                                              * during scrolling; the event
-                                              * should be used for
-                                              * informational purposes and
-                                              * maybe some indications
-                                              * visually, but not actually
-                                              * perform anything */
-} Evas_Event_Flags;
-
 /** State of Evas_Coord_Touch_Point
  *
  * @ingroup Evas
@@ -293,6 +146,45 @@ typedef enum
                       */
 } Evas_Callback_Type;
 
+/** Possible orientation options for evas_object_image_orient_set().
+ *
+ * @since 1.14
+ *
+ * @ingroup Evas_Image
+ */
+typedef enum
+{
+  EVAS_IMAGE_ORIENT_NONE = 0, /** no orientation change */
+  EVAS_IMAGE_ORIENT_0 = 0, /** no orientation change */
+  EVAS_IMAGE_ORIENT_90 = 1, /** orient 90 degrees clockwise */
+  EVAS_IMAGE_ORIENT_180 = 2, /** orient 180 degrees clockwise */
+  EVAS_IMAGE_ORIENT_270 = 3, /** rotate 90 degrees counter-clockwise (i.e. 270
+                              * degrees clockwise) */
+  EVAS_IMAGE_FLIP_HORIZONTAL = 4, /** flip image horizontally */
+  EVAS_IMAGE_FLIP_VERTICAL = 5, /** flip image vertically */
+  EVAS_IMAGE_FLIP_TRANSPOSE = 6, /** flip image along the y = (width - x) line
+                                  * (bottom-left to top-right) */
+  EVAS_IMAGE_FLIP_TRANSVERSE = 7 /** flip image along the y = x line (top-left
+                                  * to bottom-right) */
+} Evas_Image_Orient;
+
+/** How an image's center region (the complement to the border region) should
+ * be rendered by Evas
+ *
+ * @ingroup Evas
+ */
+typedef enum
+{
+  EVAS_BORDER_FILL_NONE = 0, /** Image's center region is @c b not to be
+                              * rendered */
+  EVAS_BORDER_FILL_DEFAULT = 1, /** Image's center region is to be @c b blended
+                                 * with objects underneath it, if it has
+                                 * transparency. This is the default behavior
+                                 * for image objects */
+  EVAS_BORDER_FILL_SOLID = 2 /** Image's center region is to be made solid,
+                              * even if it has transparency on it */
+} Evas_Border_Fill_Mode;
+
 /** An opaque type containing information on which modifier keys are registered
  * in an Evas canvas
  *
@@ -368,6 +260,7 @@ typedef enum
                                       *
                                       * @since 1.14 */
   EVAS_CANVAS3D_STATE_SCENE_SHADOWS_DEPTH,
+  EVAS_CANVAS3D_STATE_SCENE_RENDER_TO_TEXTURE,
   EVAS_CANVAS3D_STATE_TEXTURE_DATA = 1,
   EVAS_CANVAS3D_STATE_TEXTURE_WRAP,
   EVAS_CANVAS3D_STATE_TEXTURE_FILTER,
@@ -381,7 +274,7 @@ typedef enum
   EVAS_CANVAS3D_STATE_MESH_VERTEX_DATA,
   EVAS_CANVAS3D_STATE_MESH_INDEX_DATA,
   EVAS_CANVAS3D_STATE_MESH_VERTEX_ASSEMBLY,
-  EVAS_CANVAS3D_STATE_MESH_SHADE_MODE,
+  EVAS_CANVAS3D_STATE_MESH_SHADER_MODE,
   EVAS_CANVAS3D_STATE_MESH_FOG,
   EVAS_CANVAS3D_STATE_MESH_BLENDING,
   EVAS_CANVAS3D_STATE_MESH_ALPHA_TEST,
@@ -403,7 +296,7 @@ typedef enum
   EVAS_CANVAS3D_STATE_NODE_MESH_GEOMETRY,
   EVAS_CANVAS3D_STATE_NODE_MESH_MATERIAL,
   EVAS_CANVAS3D_STATE_NODE_MESH_FRAME,
-  EVAS_CANVAS3D_STATE_NODE_MESH_SHADE_MODE,
+  EVAS_CANVAS3D_STATE_NODE_MESH_SHADER_MODE,
   EVAS_CANVAS3D_STATE_NODE_MESH_MATERIAL_ID,
   EVAS_CANVAS3D_STATE_NODE_LIGHT,
   EVAS_CANVAS3D_STATE_NODE_CAMERA,
@@ -411,9 +304,12 @@ typedef enum
   EVAS_CANVAS3D_STATE_NODE_PARENT_ORIENTATION,
   EVAS_CANVAS3D_STATE_NODE_PARENT_SCALE,
   EVAS_CANVAS3D_STATE_NODE_MEMBER,
-  EVAS_CANVAS3D_STATE_NODE_PARENT_BILLBOARD /** No description supplied.
-                                             *
-                                             * @since 1.14 */
+  EVAS_CANVAS3D_STATE_NODE_PARENT_BILLBOARD, /** No description supplied.
+                                              *
+                                              * @since 1.14 */
+  EVAS_CANVAS3D_STATE_NODE_LOD /** No description supplied.
+                                *
+                                * @since 1.18 */
 } Evas_Canvas3D_State;
 
 /** Transform space
@@ -636,19 +532,21 @@ typedef enum
  */
 typedef enum
 {
-  EVAS_CANVAS3D_SHADE_MODE_VERTEX_COLOR = 0, /** Shaded using vertex color
-                                              * attribute */
-  EVAS_CANVAS3D_SHADE_MODE_DIFFUSE, /** Shaded using material diffuse term */
-  EVAS_CANVAS3D_SHADE_MODE_FLAT, /** Per-vertex flat lighting */
-  EVAS_CANVAS3D_SHADE_MODE_PHONG, /** Per-pixel phong shading */
-  EVAS_CANVAS3D_SHADE_MODE_NORMAL_MAP, /** Per-pixel normal map shading */
-  EVAS_CANVAS3D_SHADE_MODE_SHADOW_MAP_RENDER, /** Fragment color is defined by
-                                               * its z-coord */
-  EVAS_CANVAS3D_SHADE_MODE_COLOR_PICK, /** Rendering to additional frame bufer
-                                        */
-  EVAS_CANVAS3D_SHADE_MODE_PARALLAX_OCCLUSION /** Per-pixel parallax occlusion
-                                               * map shading */
-} Evas_Canvas3D_Shade_Mode;
+  EVAS_CANVAS3D_SHADER_MODE_VERTEX_COLOR = 0, /** Shaded using vertex color
+                                               * attribute */
+  EVAS_CANVAS3D_SHADER_MODE_DIFFUSE, /** Shaded using material diffuse term */
+  EVAS_CANVAS3D_SHADER_MODE_FLAT, /** Per-vertex flat lighting */
+  EVAS_CANVAS3D_SHADER_MODE_PHONG, /** Per-pixel phong shading */
+  EVAS_CANVAS3D_SHADER_MODE_NORMAL_MAP, /** Per-pixel normal map shading */
+  EVAS_CANVAS3D_SHADER_MODE_SHADOW_MAP_RENDER, /** Fragment color is defined by
+                                                * its z-coord */
+  EVAS_CANVAS3D_SHADER_MODE_COLOR_PICK, /** Rendering to additional frame bufer
+                                         */
+  EVAS_CANVAS3D_SHADER_MODE_PARALLAX_OCCLUSION, /** Per-pixel parallax
+                                                 * occlusion map shading */
+  EVAS_CANVAS3D_SHADER_MODE_POST_PROCESSING_FXAA /** Render full screen quard
+                                                  */
+} Evas_Canvas3D_Shader_Mode;
 
 /** Vertex attribute IDs
  *
@@ -739,6 +637,8 @@ typedef enum
   EVAS_CANVAS3D_MATERIAL_ATTRIB_NORMAL /** Normal map term */
 } Evas_Canvas3D_Material_Attrib;
 
+typedef struct _Efl_Canvas_Text_Annotation Efl_Canvas_Text_Annotation;
+
 
 #endif
 
